@@ -35,6 +35,7 @@ fn main() {
     let pd_source = libpd_dir.join("pure-data").join("src");
     let libpd_wrapper_dir = libpd_dir.join("libpd_wrapper");
     let libpd_wrapper_util_dir = libpd_wrapper_dir.join("util");
+    let externals_dir = libpd_wrapper_dir.join("libpd_rs_bundled").join("externals");
 
     // Transform values of the #include fields in libpd sources to include right paths.
     // Somehow the build script complains if they don't include relative paths but just header names.
@@ -128,6 +129,22 @@ fn main() {
             .cflag(format!("-I{}", pd_source.to_str().unwrap()))
             .cflag(format!("-I{}", libpd_wrapper_dir.to_str().unwrap()))
             .cflag(format!("-I{}", libpd_wrapper_util_dir.to_str().unwrap()))
+            .cflag(format!(
+                "-I{}",
+                externals_dir.join("freeverb").to_str().unwrap()
+            ))
+            .cflag(format!(
+                "-I{}",
+                externals_dir.join("ggee").to_str().unwrap()
+            ))
+            .cflag(format!(
+                "-I{}",
+                libpd_wrapper_dir
+                    .join("libpd_rs_bundled")
+                    .join("header")
+                    .to_str()
+                    .unwrap()
+            ))
             .cflag(format!("-DPD_FLOATSIZE={PD_FLOATSIZE}"))
             .define("CMAKE_THREAD_LIBS_INIT", pthread_lib_path.to_str().unwrap())
             .define("PTHREADS_INCLUDE_DIR", pthread_include.to_str().unwrap())
@@ -168,6 +185,22 @@ fn main() {
             .cflag(format!("-I{}", pd_source.to_str().unwrap()))
             .cflag(format!("-I{}", libpd_wrapper_dir.to_str().unwrap()))
             .cflag(format!("-I{}", libpd_wrapper_util_dir.to_str().unwrap()))
+            .cflag(format!(
+                "-I{}",
+                externals_dir.join("freeverb").to_str().unwrap()
+            ))
+            .cflag(format!(
+                "-I{}",
+                externals_dir.join("ggee").to_str().unwrap()
+            ))
+            .cflag(format!(
+                "-I{}",
+                libpd_wrapper_dir
+                    .join("libpd_rs_bundled")
+                    .join("header")
+                    .to_str()
+                    .unwrap()
+            ))
             .cflag(format!("-DPD_FLOATSIZE={PD_FLOATSIZE}"))
             .no_build_target(true)
             .always_configure(true)
@@ -194,6 +227,22 @@ fn main() {
             .cflag(format!("-I{}", pd_source.to_str().unwrap()))
             .cflag(format!("-I{}", libpd_wrapper_dir.to_str().unwrap()))
             .cflag(format!("-I{}", libpd_wrapper_util_dir.to_str().unwrap()))
+            .cflag(format!(
+                "-I{}",
+                externals_dir.join("freeverb").to_str().unwrap()
+            ))
+            .cflag(format!(
+                "-I{}",
+                externals_dir.join("ggee").to_str().unwrap()
+            ))
+            .cflag(format!(
+                "-I{}",
+                libpd_wrapper_dir
+                    .join("libpd_rs_bundled")
+                    .join("header")
+                    .to_str()
+                    .unwrap()
+            ))
             .cflag(format!("-DPD_FLOATSIZE={PD_FLOATSIZE}"))
             .define("CMAKE_OSX_ARCHITECTURES", "x86_64;arm64")
             .no_build_target(true)
